@@ -10,7 +10,7 @@ use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.032001";
+$VERSION = "5.036003";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.32.1) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.36.3) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.32.1
-    or die sprintf "%s: Perl lib version (5.32.1) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.36.3
+    or die sprintf "%s: Perl lib version (5.36.3) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -84,7 +84,7 @@ sub AUTOLOAD {
 
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
-    archlibexp => '/opt/local/lib/perl5/5.32/darwin-thread-multi-2level',
+    archlibexp => '/opt/local/lib/perl5/5.36/darwin-thread-multi-2level',
     archname => 'darwin-thread-multi-2level',
     cc => '/usr/bin/cc',
     d_readlink => 'define',
@@ -96,16 +96,16 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'DYLD_LIBRARY_PATH',
-    libpth => '/opt/local/lib /Library/Developer/CommandLineTools/usr/lib/clang/16/lib /Library/Developer/CommandLineTools/SDKs/MacOSX15.sdk/usr/lib /Library/Developer/CommandLineTools/usr/lib /usr/lib',
+    libpth => '/opt/local/lib /Library/Developer/CommandLineTools/usr/lib/clang/16/lib /Library/Developer/CommandLineTools/SDKs/MacOSX15.2.sdk/usr/lib /Library/Developer/CommandLineTools/usr/lib /usr/lib',
     osname => 'darwin',
     osvers => '24.3.0',
     path_sep => ':',
-    privlibexp => '/opt/local/lib/perl5/5.32',
+    privlibexp => '/opt/local/lib/perl5/5.36',
     scriptdir => '/opt/local/bin',
-    sitearchexp => '/opt/local/lib/perl5/site_perl/5.32/darwin-thread-multi-2level',
-    sitelibexp => '/opt/local/lib/perl5/site_perl/5.32',
+    sitearchexp => '/opt/local/lib/perl5/site_perl/5.36/darwin-thread-multi-2level',
+    sitelibexp => '/opt/local/lib/perl5/site_perl/5.36',
     so => 'dylib',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.32.1',
+    version => '5.36.3',
 };
